@@ -114,6 +114,14 @@ def temporary_token(sst):
         raise ValueError(response.content)
 
     return temp_token
+def get_header():
+    header = {
+        "Accept": "application/json",
+        "Content-Type": "application/json",
+        "User-Agent": get_useragent(),
+        "X-GDC-AuthTT": auth_cookie()
+    }
+    return header
 
 def execute_schedule(schedule_id, retry=False):
     """ Executes GoodData schedule.
@@ -154,18 +162,11 @@ def execute_schedule(schedule_id, retry=False):
     })
 
     api_url = os.getenv('GOODDATA_DOMAIN') + "/gdc/projects/" + os.getenv('GOODDATA_PROJECT') + "/schedules/" + schedule_id + "/executions"
-    
-    headers = {
-        "Accept": "application/json",
-        "Content-Type": "application/json",
-        "User-Agent": get_useragent(),
-        "X-GDC-AuthTT": auth_cookie()
-    }
 
     response = requests.post(
         url=api_url, 
         data=values,
-        headers=headers
+        headers=get_header()
     )
 
     if 200 <= response.status_code < 300:
@@ -174,7 +175,7 @@ def execute_schedule(schedule_id, retry=False):
         while True:
             response = requests.get(
                 url=uri,
-                headers=headers
+                headers=get_header()
             )   
             content = json.loads(response.content)
             status = content['execution']['status']
